@@ -30,6 +30,7 @@ import android.widget.TextView;
 
 import org.videolan.libvlc.Media;
 import org.videolan.vlc.R;
+import org.videolan.vlc.util.Strings;
 
 public class MediaInfoAdapter extends ArrayAdapter<Media.Track> {
 
@@ -43,10 +44,10 @@ public class MediaInfoAdapter extends ArrayAdapter<Media.Track> {
         View v = convertView;
         if (v == null) {
             LayoutInflater inflater = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
-            v = inflater.inflate(R.layout.list_item, parent, false);
+            v = inflater.inflate(R.layout.info_item, parent, false);
             holder = new ViewHolder();
             holder.title = (TextView) v.findViewById(R.id.title);
-            holder.text = (TextView) v.findViewById(R.id.artist);
+            holder.text = (TextView) v.findViewById(R.id.subtitle);
             v.setTag(holder);
         } else
             holder = (ViewHolder) v.getTag();
@@ -82,6 +83,8 @@ public class MediaInfoAdapter extends ArrayAdapter<Media.Track> {
     }
 
     private void appendCommon(StringBuilder textBuilder, Resources res, Media.Track track) {
+        if (track.bitrate != 0)
+            textBuilder.append(res.getString(R.string.track_bitrate_info, Strings.readableSize(track.bitrate)));
         textBuilder.append(res.getString(R.string.track_codec_info, track.codec));
         if (track.language != null && !track.language.equalsIgnoreCase("und"))
             textBuilder.append(res.getString(R.string.track_language_info, track.language));
